# -*- mode: rpm-spec -*-

%define aurox_ver 11.0
%define rel 1


%define desktop_vendor aurox
%define menu_level Base

# By default, this spec file will generate RPMs for Clisp, CMUCL
# and GCL. This can be changed by modifying the variables below.
%define enable_clisp 0
%define enable_cmucl 0
%define enable_gcl 1

%define debug_package %{nil}

%define clisp_version 2.29

%if %enable_clisp
%define clisp_flags	--enable-clisp
%else
%define clisp_flags	--disable-clisp
%endif

%if %enable_cmucl
%define cmucl_flags	--enable-cmucl
%else
%define cmucl_flags	--disable-cmucl
%endif

%if %enable_gcl
%define gcl_flags	--enable-gcl
%else
%define gcl_flags	--disable-gcl
%endif

# Inhibit automatic compressing of info files. Compressed info
# files break maxima's internal help.
%define __spec_install_post /bin/true

Summary: Maxima Symbolic Computation Program
Name: maxima
Version: 5.9.1
Release: %{aurox_ver}.aur.%{rel}
License: GPL
Group: Sciences/Mathematics
URL: http://maxima.sourceforge.net
Source0: %{name}-%{version}.tar.gz
Source1: x%{name}.desktop
Source2: %{name}.png
Source3: %{name}-init.lisp
Source10: breqn.sty
Source11: cmbase.sym
Source12: flexisym.sty
Source13: mathstyle.sty

BuildRoot: %{_tmppath}/%{name}-%{version}-buildroot
Requires: maxima_exec
Requires: tk gnuplot
BuildRequires:	texinfo tetex
%if %{enable_clisp}
BuildRequires:	clisp
%endif
%if %{enable_cmucl}
BuildRequires:	cmucl
%endif
%if %{enable_gcl}
BuildRequires:	gcl
%endif

%description

Maxima is a full symbolic computation program.  It is full featured
doing symbolic manipulation of polynomials, matrices, rational
functions, integration, Todd-coxeter, graphing, bigfloats.  It has a
symbolic debugger source level debugger for maxima code.  Maxima is
based on the original Macsyma developed at MIT in the 1970's.  It is
quite reliable, and has good garbage collection, and no memory leaks.
It comes with hundreds of self tests.

%package docs
Summary: Documentation for Maxima
Group: Sciences/Mathematics

%description docs
Additional documentation for Maxima. 

Browsable HTML documentation is contained in basic maxima package.
Additional PostScript documents are here.

%package xmaxima
Summary: Tcl/Tk interface to Maxima
Group: Sciences/Mathematics
Requires: maxima tk
Provides: xmaxima
%description xmaxima
Tcl/Tk interface to Maxima.

%if %{enable_clisp}
%package exec-clisp
Summary: Maxima compiled with clisp
Group: Sciences/Mathematics
Requires: clisp = %{clisp_version}, maxima
Provides: maxima_exec
%description exec-clisp
Maxima compiled with clisp.
%endif

%if %{enable_cmucl}
%package exec-cmucl
Summary: Maxima compiled with CMUCL
Group: Sciences/Mathematics
Requires: cmucl maxima
Provides: maxima_exec
%description exec-cmucl
Maxima compiled with CMUCL.
%endif

%if %{enable_gcl}
%package exec-gcl
Summary: Maxima compiled with GCL
Group: Sciences/Mathematics
Requires: maxima
Provides: maxima_exec
%description exec-gcl
Maxima compiled with Gnu Common Lisp.
%endif

%prep
%setup -q
%configure %{clisp_flags} %{gcl_flags} %{cmucl_flags}

%build
make

 more docs:
cp -f interfaces/emacs/emaxima/emaxima.sty doc/maximabook
cp -f %{SOURCE10} doc/maximabook
cp -f %{SOURCE11} doc/maximabook
cp -f %{SOURCE12} doc/maximabook
cp -f %{SOURCE13} doc/maximabook
pushd doc/maximabook
#  make
popd


%install
rm -rf %{buildroot}
%makeinstall

mkdir -p %{buildroot}%{_datadir}/applications
desktop-file-install --vendor %{desktop_vendor} \
  --dir %{buildroot}%{_datadir}/applications    \
  --add-category X-Aurox-%{menu_level}          \
  --add-category Application                    \
  --add-category Education                      \
  %{SOURCE1}

mkdir -p %{buildroot}%{_datadir}/pixmaps
install -m 0644 %{SOURCE2} %{buildroot}%{_datadir}/pixmaps/
install -m 0644 %{SOURCE3} %{buildroot}%{_datadir}/maxima/%{version}/share/

#mv -f %{buildroot}%{_datadir}/maxima/%{version}/doc doc2

#it in maxima-docs
rm -f %{buildroot}%{_datadir}/maxima/%{version}/doc/EMaximaIntro.ps
rm -f %{buildroot}%{_datadir}/maxima/%{version}/doc/maximabook/maxima.pdf

rm -f %{buildroot}%{_infodir}/dir

#gzip -9nf %{buildroot}%{_infodir}/maxima.info*
gzip -9nf %{buildroot}%{_mandir}/man1/maxima.*

%post
/sbin/install-info %{_infodir}/maxima.info %{_infodir}/dir

%preun
if [ "$1" = 0 ]; then
	/sbin/install-info --delete %{_infodir}/maxima.info %{_infodir}/dir
fi

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%{_datadir}/maxima/%{version}/demo
%{_datadir}/maxima/%{version}/emacs
%{_datadir}/maxima/%{version}/share
%{_datadir}/maxima/%{version}/src
%{_datadir}/maxima/%{version}/tests
%{_datadir}/maxima/%{version}/doc
%{_libexecdir}/maxima/%{version}
%{_infodir}/maxima.info*
%{_mandir}/man1/maxima.1.gz
%{_bindir}/maxima
%{_bindir}/rmaxima
%doc AUTHORS COPYING INSTALL README README.lisps README.rpms

%files docs
%defattr(-,root,root,-)
%doc doc/emaxima/EMaximaIntro.ps 
#%doc doc/maximabook/maxima.ps
#%doc doc/maximabook/maxima.pdf

%files xmaxima
%defattr(-,root,root,-)
%{_bindir}/xmaxima
%{_datadir}/applications/*.desktop
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/maxima/%{version}/xmaxima

%if %{enable_clisp}
%files exec-clisp
%defattr(-,root,root,-)
%{_libdir}/maxima/%{version}/binary-clisp/*
%endif

%if %{enable_cmucl}
%files exec-cmucl
%defattr(-,root,root,-)
%{_libdir}/maxima/%{version}/binary-cmucl/*
%endif

%if %{enable_gcl}
%files exec-gcl
%defattr(-,root,root,-)
%{_libdir}/maxima/%{version}/binary-gcl/*
%endif

%changelog
* Thu Aug 04 2005 Rafal Kwasny <rkwasny@aurox.org> 5.9.1-11.0.aur.1
- Rebuilt.
- dropped optional documetation due to build errors

* Fri Nov 12 2004 Aurox Team <aurox@aurox.org> 0:5.9.1-10.1.aur.4
- New version 5.9.1

* Sat Apr  5 2003 Robert Glowczynski <robertg@software.com.pl> 5.9.0-4aur
- Package postscript docs as separate rpm

* Fri Apr  4 2003 Robert Glowczynski <robertg@software.com.pl> 5.9.0-3aur
- Remove info/dir; compress info files and man page
- Move xmaxima's html files to xmaxima package; add info on
   maxima html docs; move EMaximaIntro.ps to doc
- make maxima book; package *.ps only (ggv has problems with pdf)
- Rebuild with gcl 2.5.2 for Aurox 9

* Thu Apr  3 2003 Robert Glowczynski <robertg@software.com.pl>
- spec file partially merged with Mandrake's version

* Sat Jan  4 2003 James Amundson <amundson@fnal.gov>
- Added doc files
- Added explicit clisp version
- Added conditional to postun
- Renamed exec_* packages to exec-*
- Use rpm macros instead of hard-coded paths
- Thanks to Rex Dieter for helpful suggestions

* Sun Sep  8 2002 James Amundson <amundson@fnal.gov> 
- Initial build.
